@@ -4,10 +4,6 @@
 
 import warnings
 import re
-warnings.filterwarnings('always',
-                        category=DeprecationWarning,
-                        module='^{0}'.format(re.escape(__name__)))
-
 from .version import version as __version__
 
 # And all the librosa sub-modules
@@ -15,7 +11,6 @@ from . import cache
 from . import core
 from . import beat
 from . import decompose
-from . import display
 from . import effects
 from . import feature
 from . import filters
@@ -25,10 +20,11 @@ from . import segment
 from . import util
 
 # Exporting exception classes at the top level
-from .util.exceptions import * # pylint: disable=wildcard-import
+from .util.exceptions import *  # pylint: disable=wildcard-import
 
 # Exporting all core functions is okay here: suppress the import warning
-from librosa.core import *  # pylint: disable=wildcard-import
-
-
+from .core import *  # pylint: disable=wildcard-import
 
+warnings.filterwarnings('always',
+                        category=DeprecationWarning,
+                        module='^{0}'.format(re.escape(__name__)))
